@@ -83,7 +83,9 @@ class Messageable:
             self,
             content: Optional[str] = ...,
             *,
-            tts: bool = ...,
+            embed: Embed = ...,
+            ark: Ark = ...,
+            delete_after: float = ...,
             image: str = ...,
             reference: Union[Message, MessageReference, PartialMessage] = ...,
             mention_author: Member = ...,
@@ -98,7 +100,8 @@ class Messageable:
             reference=None,
             mention_author=None,
             ark=None,
-            embed=None
+            embed=None,
+            delete_after = None,
     ):
         """|coro|
         使用给定的内容向目的地发送消息。
@@ -117,9 +120,10 @@ class Messageable:
             要发送的 Embed 类
         reference: Union[:class:`~qq.Message`, :class:`~qq.MessageReference`, :class:`~qq.PartialMessage`]
             对您正在回复的 :class:`~qq.Message` 的引用，可以使用 :meth:`~qq.Message.to_reference` 创建或直接作为 :class:`~qq.Message` 传递。
-        mention_author: Optional[:class:`Member`]
+        mention_author: Optional[:class:`qq.Member`]
             如果设置了，将会在消息前面提及该用户。
-
+        delete_after: Optional[:class:`float`]
+            如果设置了，则等待该秒数之后自动撤回消息。如果删除失败，则它会被静默忽略。
 
         Raises
         --------
@@ -164,6 +168,8 @@ class Messageable:
             return None
 
         ret = state.create_message(channel=channel, data=data)
+        if delete_after is not None:
+            await ret.delete(delay=delete_after)
         return ret
 
     async def fetch_message(self, id: int, /) -> Message:
