@@ -22,6 +22,7 @@
 from __future__ import annotations
 
 import asyncio
+import concurrent.futures
 import copy
 import inspect
 import itertools
@@ -145,6 +146,7 @@ class ConnectionState:
         self.application_id: Optional[int] = options.get('application_id')
         self.heartbeat_timeout: float = options.get('heartbeat_timeout', 60.0)
         self.guild_ready_timeout: float = options.get('guild_ready_timeout', 2.0)
+        self.pool = concurrent.futures.ThreadPoolExecutor()
         if self.guild_ready_timeout < 0:
             raise ValueError('guild_ready_timeout 不能为负')
 
@@ -389,7 +391,10 @@ class ConnectionState:
                 pass
             else:
                 self.application_id = application.get('id')
-        for guild_data in self.http._sync_get_guilds():
+
+        result = asyncio.run(self.http.get_guilds())
+
+        for guild_data in result:
             self._add_guild_from_data(guild_data)
 
         self.dispatch('connect')
@@ -400,7 +405,6 @@ class ConnectionState:
 
     def parse_at_message_create(self, data) -> None:
         channel, _ = self._get_guild_channel(data)
-        data['content'] = data['content'].replace(self.user.mention, '').strip()
         # channel would be the correct type here
         message = Message(channel=channel, data=data, state=self)  # type: ignore
         self.dispatch('message', message)
@@ -512,7 +516,7 @@ class ConnectionState:
                 self.dispatch('user_update', user_update[0], user_update[1])
 
             guild._add_member(member)
-            _log.debug('GUILD_MEMBER_UPDATE 引用了一个未知的频道 ID：%s。丢弃。', user_id)
+            _log.debug('GUILD_MEMBER_UPDATE 引用了一个未知的成员 ID：%s。丢弃。', user_id)
 
     def _get_create_guild(self, data):
         return self._add_guild_from_data(data)
@@ -832,7 +836,9 @@ class AutoShardedConnectionState(ConnectionState):
             else:
                 self.application_id = application.get('id')
 
-        for guild_data in self.http._sync_get_guilds():
+        result = self.pool.submit(asyncio.run, self.http.get_guilds()).result()
+
+        for guild_data in result:
             self._add_guild_from_data(guild_data)
 
         if self._messages:
